=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2010-03-25 22:22:24 +0000
+++ drizzled/sql_table.cc	2010-03-26 19:56:34 +0000
@@ -1317,7 +1317,7 @@
         return error;
       }
 
-      my_error(ER_TABLE_EXISTS_ERROR, MYF(0), identifier.getTableName().c_str());
+      my_error(ER_TABLE_EXISTS_ERROR, MYF(0), identifier.getSQLPath().c_str());
       return error;
     }
 

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2010-03-26 03:29:01 +0000
+++ drizzled/statement/alter_table.cc	2010-03-26 19:56:34 +0000
@@ -1122,6 +1122,13 @@
 
       return true;
     }
+
+    new_table_identifier.setPath(new_table_as_temporary.getPath());
+
+    if (mysql_rename_table(new_engine, new_table_as_temporary, new_table_identifier, FN_FROM_IS_TMP) != 0)
+    {
+      return true;
+    }
   }
   // Normal table success
   else

=== modified file 'drizzled/table_identifier.h'
--- drizzled/table_identifier.h	2010-03-25 20:50:51 +0000
+++ drizzled/table_identifier.h	2010-03-26 19:56:34 +0000
@@ -71,13 +71,13 @@
                    Type tmp_arg= message::Table::STANDARD) :
     type(tmp_arg),
     db(db_arg),
-    table_name(table_name_arg),
-    lower_db(db_arg),
-    lower_table_name(table_name_arg)
+    table_name(table_name_arg)
   { 
   }
 
-  TableIdentifier(const std::string &schema_name_arg, const std::string &table_name_arg, const std::string &path_arg ) :
+  TableIdentifier( const std::string &schema_name_arg,
+                   const std::string &table_name_arg,
+                   const std::string &path_arg ) :
     type(message::Table::TEMPORARY),
     path(path_arg),
     db(schema_name_arg),
@@ -101,6 +101,11 @@
 
   const std::string &getPath();
 
+  void setPath(const std::string &new_path)
+  {
+    path= new_path;
+  }
+
   const std::string &getDBName() const
   {
     return db;
@@ -144,6 +149,8 @@
     }
 
     output << type_str;
+    output << ", ";
+    output << identifier.path;
     output << ")";
 
     return output;  // for multiple << operators.

=== modified file 'drizzled/table_share.h'
--- drizzled/table_share.h	2010-03-25 20:50:51 +0000
+++ drizzled/table_share.h	2010-03-26 19:56:34 +0000
@@ -213,6 +213,11 @@
     return table_name.str;
   }
 
+  const char *getPath() const
+  {
+    return path.str;
+  }
+
   const std::string &getTableName(std::string &name_arg) const
   {
     name_arg.clear();
@@ -619,6 +624,21 @@
   static TableShare *getShare(Session *session, 
                               TableList *table_list, char *key,
                               uint32_t key_length, uint32_t, int *error);
+
+  friend std::ostream& operator<<(std::ostream& output, const TableShare &share)
+  {
+    output << "TableShare:(";
+    output <<  share.getSchemaName();
+    output << ", ";
+    output << share.getTableName();
+    output << ", ";
+    output << share.getTableTypeAsString();
+    output << ", ";
+    output << share.getPath();
+    output << ")";
+
+    return output;  // for multiple << operators.
+  }
 };
 
 } /* namespace drizzled */

=== modified file 'plugin/innobase/handler/ha_innodb.cc'
--- plugin/innobase/handler/ha_innodb.cc	2010-03-25 00:11:02 +0000
+++ plugin/innobase/handler/ha_innodb.cc	2010-03-26 19:56:34 +0000
@@ -6043,6 +6043,13 @@
 @return	0 or error code */
 UNIV_INTERN int InnobaseEngine::doRenameTable(Session &session, TableIdentifier &from, TableIdentifier &to)
 {
+        // A temp table alter table/rename is a shallow rename and only the
+        // definition needs to be updated.
+        if (to.getType() == message::Table::TEMPORARY && from.getType() == message::Table::TEMPORARY)
+        {
+          return 0;
+        }
+
 	trx_t*	trx;
 	int	error;
 	trx_t*	parent_trx;

=== modified file 'tests/r/temp_table.result'
--- tests/r/temp_table.result	2010-03-25 18:47:05 +0000
+++ tests/r/temp_table.result	2010-03-26 19:56:34 +0000
@@ -26,7 +26,7 @@
 Warnings:
 Note	1050	Table 't2' already exists
 CREATE TEMPORARY TABLE t1 (a int not null, b char (10) not null);
-ERROR 42S01: Table 't1' already exists
+ERROR 42S01: Table 'test.#t1' already exists
 ALTER TABLE t1 RENAME t2;
 ERROR 42S01: Table 'test.#t2' already exists
 select * from t2;

